﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

using System.Net;
using System.IO;

using System.Web; //Add reference to System.Web
using System.Runtime.Serialization.Json; //Add reference to System.Runtime.Serialization

namespace RedCritterConnecter.Samples
{
    //Create a class to contain the response

    public class GetUserProfileVersionResponse
    {   
        public Boolean Result { get; set; }
        public String UserID { get; set; }
        public String Version { get; set; }
        public String VersionAccolades { get; set; }
        public String VersionAppDomains { get; set; }
        public String VersionApps { get; set; }
        public String VersionBadges { get; set; }
        public String VersionCerts { get; set; }
        public String VersionFeed { get; set; }
        public String VersionLeaderboards { get; set; }
        public String VersionProfile { get; set; }
        public String VersionRewards { get; set; }
        public String VersionSkills { get; set; }
    }


    public class GetUserProfileVersion
    {

        public delegate void OnGetUserProfileVersionResponse(GetUserProfileVersionResponse GetUserProfileVersionResponse);
        public event OnGetUserProfileVersionResponse onGetUserProfileVersionResponse;

        public delegate void OnGetUserProfileVersionResponseError(GetUserProfileVersionResponse GetUserProfileVersionResponse);
        public event OnGetUserProfileVersionResponseError onGetUserProfileVersionResponseError;

        const string CONST_ConnecterBaseURL = "https://www.redcritterconnecter.com/";

        public void Execute(String UserID)
        {
            try
            {
                //Create url encoded parameters in query string
                String queryString = "userid=" + System.Web.HttpUtility.UrlEncode(UserID);

                //Create a new instance of a WebClient
                WebClient wc = new System.Net.WebClient();

                //Prevent this request from caching in order to ensure that it is sent to server
                wc.CachePolicy = new System.Net.Cache.RequestCachePolicy(System.Net.Cache.RequestCacheLevel.NoCacheNoStore);

                //Attach an event handler to receive the response
                wc.DownloadStringCompleted += onGetUserProfileVersionResponseReceived;

                //Make the call
                            
                wc.DownloadStringAsync(new Uri(CONST_ConnecterBaseURL + "services/gamificationv1/GetUserProfileVersion?" + queryString, UriKind.Absolute));
            }
            catch
            {
                //Something went wrong communicating with the server
                if (onGetUserProfileVersionResponseError != null)
                {
                    onGetUserProfileVersionResponseError(null);
                }
            }

        }

        private void onGetUserProfileVersionResponseReceived(object sender, DownloadStringCompletedEventArgs e)
        {
            try
            {
                //Create a JSON serializer
                System.Runtime.Serialization.Json.DataContractJsonSerializer s = new DataContractJsonSerializer(typeof(GetUserProfileVersionResponse));
               

                //Copy the string into a memory stream
                MemoryStream ms = new MemoryStream(Encoding.UTF8.GetBytes(e.Result));

                //Read the stream into an object matching the response's type
                GetUserProfileVersionResponse GetUserProfileVersionResponse = (GetUserProfileVersionResponse)s.ReadObject(ms);

                //Work with the populated response object
                if (GetUserProfileVersionResponse.Result == true)
                {
                    //Request was accepted, raise the success event
                    onGetUserProfileVersionResponse(GetUserProfileVersionResponse);
                }
                else
                {
                    //Something went wrong
                    if (onGetUserProfileVersionResponseError != null)
                    {
                        //Request failed, raise the error event
                        onGetUserProfileVersionResponseError(GetUserProfileVersionResponse);
                    }
                }
            }
            catch
            {
                //Something went wrong
                onGetUserProfileVersionResponseError(null);
            }
        }
    }
}
